{ config, pkgs, ... }:

{
  imports =
    [
      ../../base.nix
      ../../common/metrics-exporters.nix
      ./hardware-configuration.nix
      ./filesystems.nix
      ./wireguard.nix
      ./exports.nix

      ./services/snappymail.nix
      #./vms.nix

      ./services/nginx
      ./services/postgres.nix
      ./services/kanidm.nix
      ./services/matrix
      ./services/jellyfin.nix
      ./services/transmission.nix
      ./services/metrics
      ./services/flame.nix
      ./services/gitea.nix
      ./services/hedgedoc.nix
      ./services/vaultwarden.nix
      ./services/calibre.nix
      ./services/fancontrol.nix
      # ./services/code-server.nix

  ];

  networking = {
    hostName = "voyager";
    defaultGateway = "192.168.10.1";
    nameservers = [ "192.168.11.100" "1.1.1.1" ];
    interfaces.eno1.ipv4 = {
      addresses = [
      { address = "192.168.10.165"; prefixLength = 24; }
      ];
    };
    hostId = "8e84b235";
  };

  sops.defaultSopsFile = ../../secrets/voyager/voyager.yaml;

  environment.variables = { EDITOR = "vim"; };
  environment.systemPackages = with pkgs; [
    ((vim_configurable.override {  }).customize{
     name = "vim";
     vimrcConfig.packages.myplugins = with pkgs.vimPlugins; {
     start = [ vim-nix vim-lastplace vim-commentary ];
     opt = [];
     };
     vimrcConfig.customRC = ''
     " your custom vimrc
     set number
     set relativenumber
     set nu rnu
     set signcolumn=number

     set hlsearch
     set smartcase
     set incsearch

     set autoindent
     set expandtab
     set shiftwidth=2
     set tabstop=2
     set smartindent
     set smarttab

     set ruler

     set undolevels=1000

     set nocompatible
     set backspace=indent,eol,start
     " Turn on syntax highlighting by default
     syntax on
     " ...
     '';
    }
  )
    zfs
    screen
    exa
  ];

  services.snappymail = {
    enable = true;
    hostname = "mail.home.feal.no";
  };
  services.nginx.virtualHosts."${config.services.snappymail.hostname}" = let
    certPath = "/etc/ssl-snakeoil/mail_home_feal_no";
  in {
    addSSL = true;

    sslCertificate    = "${certPath}.crt";
    sslCertificateKey = "${certPath}.key";
  };

  /* virtualisation.podman = { */
  /*   enable = true; */
  /*   dockerCompat = true; # Make `docker` shell alias */
  /*   defaultNetwork.settings.dns_enabled = true; */
  /* }; */

  /* virtualisation.oci-containers.backend = "podman"; */

  virtualisation.docker.enable = true;
  virtualisation.oci-containers.backend = "docker";


  networking.firewall.allowedTCPPorts = [ 22 ];

  system.stateVersion = "22.11";
}

